@@ -189,8 +189,9 @@ class hexagon_grid:
             df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
             df = df.drop_duplicates(["geometry"])
             df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            check_topology(df)
-            self.geosolution = df
+            pdf = gpd.overlay(self.data, df, how = 'union')
+            check_topology(pdf)
+            self.geosolution = pdf
         elif 0.0 < self.area_threshold <= 0.8:
             area_thres = (spacing*spacing)*self.area_threshold
             hexagon = dissolve_polygon(final_hexa, area_thres).geosolution
@@ -198,8 +199,9 @@ class hexagon_grid:
             df["geometry"] = df["geometry"].apply(lambda geom: geom.wkb)
             df = df.drop_duplicates(["geometry"])
             df["geometry"] = df["geometry"].apply(lambda geom: loads(geom))
-            check_topology(df)
-            self.geosolution = df
+            pdf = gpd.overlay(self.data, df, how = 'union')
+            check_topology(pdf)
+            self.geosolution = pdf
         else:
             raise ValueError("You shouldn't cross the upper/lower limit of area threshold.\nThreshold should be 0.0> area_threshold>=0.8")
 
@@ -409,4 +411,39 @@ class square_grid:
             area_thresholda = (length*length)*0.10
             disolve_square = dissolve_polygon(final_hexa, area_thresholda).geosolution
             check_topology(disolve_square)
-            self.geosolution = disolve_square
\ No newline at end of file
+            self.geosolution = disolve_square
+
+class calc_area:
+    
+    def __init__(self,
+                 df,
+                 delarea:float,
+                 unit_area:str = None
+                 ):
+        
+        self.df = df
+        self.delarea = delarea
+        self.unit_area = unit_area
+        
+        if isinstance(df, str):
+            data = gpd.read_file(df)
+            if data.crs == None:
+                data.crs = {'init':'epsg:4326'}
+        elif isinstance(df, gpd.GeoDataFrame):
+            data = self.df
+            if data.crs == None:
+                data.crs = {'init':'epsg:4326'}
+        else:
+            raise KeyError(f"{self.df} is errorneous data location, please fix the data location problem")
+        
+        if unit_area != None and unit_area == 'meter':
+            data['area_m'] = data.geometry.area*(100000**2)
+            ohex = data[data['area_m']>=self.delarea]
+            self.geosolution = ohex
+        else:
+            data['area_ac'] = data.geometry.area*(100000**2)/4046.86
+            ohex = data[data['area_ac']>=self.delarea]
+            self.geosolution = ohex
+        
+        
+        
\ No newline at end of file
